/* $Id: caps.hh,v 1.1 2005/07/11 21:45:39 whess Exp $ */
/* Overlord Server for the Refefree Programming Contest Judging System
 * Copyright (C) 2005 Wolfgang Hess
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
/**
 * \file caps.hh
 * \brief This file contains the server capabilities.
 */
#ifndef CAPS_HH_
#define CAPS_HH_ 1	///< protect against multiple inclusion

/// the version information of the program
#define CAP_VERSION "Overlord Server 1.0"
/// the version information shown by "-v"
#define CAP_FULLVERSION "Overlord Server (Refefree) 1.0"

#define CAP_CR_TOLERANT	///< when defined, CR (0x0d) is ignored in message headers
#define CAP_STATUS	///< when defined, the status is included in heartbeat replies
#define CAP_AUTOCONFIG	///< when defined, the auto configuration extension is supported
#define CAP_AUTOBACKUP	///< when defined, a backup of the server state is written every minute
#define CAP_SCOREBOARD	///< when defined, the scoreboard extension is supported
#define CAP_NOTIFIES	///< when defined, the notification extension is supported
#define CAP_PAUSE	///< when defined, the pause_toggle message is supported
#define CAP_CLARIFICATIONS	///< when defined, the clarification extension is supported
#define CAP_SERVERSTATUS	///< when defined, the server status extension is supported
#define CAP_LOGLOGINS	///< when defined, the server generates output for every login

/**
 * \brief When defined, max_message_size is supported.
 *
 * The configuration max_message_size can be used to set the maximal size
 * of messages that are accepted. The default is 256kB. Connections that send
 * larger messages are closed. This is to protect the server against DoS.
 * \see server_interface::set_max_message_size() and socket_interface::message_too_large()
 */
#define CAP_MAX_MESSAGE_SIZE

/**
 * \brief When defined, connection_timeout is supported.
 *
 * When support is enabled, the server sends are heartbeat request every second
 * and when no reply has been received for a certain amount of time, the
 * connection is closed. The default is 15 seconds and can be changed in
 * the configuration as connection_timeout.
 */
#define CAP_CONNECTION_TIMEOUT

#endif // CAPS_HH_
