/* $Id: exception.hh,v 1.1 2005/07/11 21:45:39 whess Exp $ */
/* Overlord Server for the Refefree Programming Contest Judging System
 * Copyright (C) 2005 Wolfgang Hess
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
/**
 * \file exception.hh
 * \brief The exception classes.
 */
#ifndef EXCEPTION_HH_
#define EXCEPTION_HH_ 1	///< protect against multiple inclusion

#include <string>
#include <exception>

/**
 * \struct fatal_exception
 * \brief Fatal exception that should result in process termination.
 * 
 * This exception is thrown when something fails that should
 * never during normal execution, e.g. file access. This exception is
 * caught by the main function.
 *
 * \see main()
 */
struct fatal_exception
{
	/// Constructs a fatal_exception with description what_
	fatal_exception(const std::string &what_) : priv_what(what_) {}
	/// getter function for the description chosen at construction time
	const std::string &what() const { return priv_what; }
	
	private:
		std::string priv_what;	///< stores the description
};

/**
 * \struct protocol_exception
 * \brief Behavior that should result in network connection termination.
 * 
 * This exception is thrown in the context of network connection processing
 * whenever a connection behaves badly, like malformed message headers and
 * message contents.
 *
 * The description usually begins with a capital letter and does not end
 * with a period.
 */
struct protocol_exception
{
	/// Constructs a protocol_exception with description what_
	protocol_exception(const std::string &what_) : priv_what(what_) {}
	/// getter function for the description chosen at construction time
	const std::string &what() const { return priv_what; }
	
	private:
		std::string priv_what;	///< stores the description
};

#endif // EXCEPTION_HH_
