/* $Id: files.hh,v 1.1 2005/07/11 21:45:39 whess Exp $ */
/* Overlord Server for the Refefree Programming Contest Judging System
 * Copyright (C) 2005 Wolfgang Hess
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
/**
 * \file files.hh
 * \brief Functions implementing the file system structure.
 *
 * Here all functions handling the 'File System Structure' as
 * described in the protocol documentation are declared.
 */
#ifndef FILES_HH_
#define FILES_HH_ 1	///< protect against multiple inclusion

#include <string>

void handle_submission(int snum, const std::string &submitter,
	const std::string &problem, const std::string &language,
	const std::string &source, int time);
bool exists_submission(int snum);
void get_submission_info(int snum, std::string &submitter,
	int &stime, std::string &problem, std::string &language);
void get_submission_state(int snum, std::string &state,
	std::string &reason, std::string &judge, std::string &lock,
	const char *suffix);
void get_submission_source(int snum, std::string &source);
bool need_submission_notification(int snum, bool judge_queries = false);
void new_submission_state(int snum, const std::string &state,
	const std::string &reason, const std::string &judge);

bool get_lock_file(const char *lockname);
void release_lock_file(const char *lockname);
bool save_server_state_backup(const std::string &backup_data_string);

void handle_clarification(int cnum, const std::string &submitter,
	const std::string &problem, const std::string &question, int time);
bool exists_clarification(int cnum);
void get_clarification_info(int cnum, std::string &submitter,
	std::string &problem, int &stime, std::string &question);
void get_clarification_state(int cnum, std::string &state,
	std::string &ctime, std::string &judge, std::string &lock,
	std::string &answer, const char *suffix);
bool need_clarification_notification(int cnum, bool &state_change,
	bool other_queries = false);
void new_clarification_state(int cnum, const std::string &state,
	int ctime, const std::string &judge, const std::string &answer);

bool update_scoreboard_file(const std::string &scoreboard_string);

#endif // FILES_HH_
