/* $Id: scoreboard.hh,v 1.1 2005/07/11 21:45:39 whess Exp $ */
/* Overlord Server for the Refefree Programming Contest Judging System
 * Copyright (C) 2005 Wolfgang Hess
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
/**
 * \file scoreboard.hh
 * \brief Function implementing the scoreboard.
 *
 * Here all structs necessary for the scoreboard function are
 * defined and the scoreboard function is declared.
 */
#ifndef SCOREBOARD_HH_
#define SCOREBOARD_HH_ 1	///< protect against multiple inclusion

#include <string>

std::string escape_xml_specials(const std::string &plain);

/**
 * \namespace scoreboard
 * \brief The namespace containing the scoreboard structs.
 */
namespace scoreboard
{

/**
 * \struct submission
 * \brief Scoreboard information about a submission
 */
struct submission
{
	std::string submitter;	///< login of the submitter
	std::string problem_id;	///< problem id for which this is a submission
	std::string state;	///< the state, new, unjudged, accepted, rejected or ignored
	int stime;	///< submission time in minutes since contest start
};

/**
 * \struct contest
 * \brief Scoreboard information about the contest
 */
struct contest
{
	std::string description;	///< the name of the contest
	int ctime;	///< current time in minutes
	int duration;	///< duration of the contest in minutes
};

/**
 * \struct problem
 * \brief Scoreboard information about a problem of the problem set
 */
struct problem
{
	std::string id;	///< id string of this problem
	std::string name;	///< full name of this problem
};

/**
 * \struct team
 * \brief Scoreboard information about a contestant
 */
struct team
{
	std::string id;	///< id string (login) of this contestant
	std::string name;	///< full name of this contestant
};

}

std::string create_scoreboard(const scoreboard::contest &c,
	const std::vector<scoreboard::problem> &P,
	const std::vector<scoreboard::team> &T,
	const std::vector<scoreboard::submission> &S,
	int penalty);

#endif // SCOREBOARD_HH_
